@@ -1,6 +1,8 @@
-from functools import wraps
 import importlib
+from functools import wraps
+
 from mongomock import MongoClient
+
 from .patches import _patch_collection_internals
 
 
@@ -174,6 +176,9 @@ class AsyncMongoMockCollection():
     def aggregate(self, *args, **kwargs) -> AsyncLatentCommandCursor:
         return AsyncLatentCommandCursor(self.__collection.aggregate(*args, **kwargs))
 
+    def list_indexes(self, *args, **kwargs) -> AsyncCursor:
+        return AsyncCursor(self.__collection.list_indexes(*args, **kwargs))
+
 
 @masquerade_class('motor.motor_asyncio.AsyncIOMotorDatabase')
 @with_async_methods('__database', [
@@ -187,7 +192,11 @@ class AsyncMongoMockDatabase():
     def __init__(self, client, database, mock_build_info=None):
         self.client = client
         self.__database = database
-        self.__build_info = mock_build_info or {'ok': 1.0, 'version': '5.0.5'}
+        self.__build_info = mock_build_info or {
+            'ok': 1.0,
+            'version': '5.0.5',
+            'versionArray': [5, 0, 5],
+        }
 
     def get_collection(self, *args, **kwargs):
         return AsyncMongoMockCollection(
@@ -204,7 +213,11 @@ class AsyncMongoMockDatabase():
         try:
             return getattr(self.__database, 'command')(*args, **kwargs)
         except NotImplementedError:
-            if args == ({'buildInfo': 1},) and not kwargs:
+            if not args:
+                raise
+            if isinstance(args[0], str) and args[0].lower() == 'buildinfo':
+                return self.__build_info
+            if isinstance(args[0], dict) and args[0] and list(args[0])[0].lower() == 'buildinfo':
                 return self.__build_info
             raise
 
@@ -229,8 +242,8 @@ class AsyncMongoMockDatabase():
     'server_info',
 ])
 class AsyncMongoMockClient():
-    def __init__(self, *args, mock_build_info=None, **kwargs):
-        self.__client = MongoClient(*args, **kwargs)
+    def __init__(self, *args, mock_build_info=None, mock_mongo_client=None, **kwargs):
+        self.__client = mock_mongo_client or MongoClient(*args, **kwargs)
         self.__build_info = mock_build_info
 
     def get_database(self, *args, **kwargs):
